Skip to contents

Normalize counts using Scaling with Ranked Subsampling (SRS) srs_normalize() uses the SRS method to equalize sampling depth to a chosen value.

Usage

srs_normalize(ta, target_reads)

Arguments

ta

A tidytacos object.

target_reads

the sequencing depth to which samples are subsampled. Samples below this threshold are discarded.

Value

A tidytacos object where the reads are subsampled to the chosen value using SRS.

See also