sample_taco() takes a random subset of samples from the original tidytacos object.
Arguments
- tt
A tidytacos object.
- n
The amount of samples that need to be returned.
- group_col
An optional name of a field in the sample table which the samples need to be evenly distributed over.
- taxon_identifier
The column that uniquely identifies a taxa
- replace
Replace selected samples so they can be picked again in sampling.
- ...
Arguments passed on to
base::samplexeither a vector of one or more elements from which to choose, or a positive integer. See ‘Details.’
sizea non-negative integer giving the number of items to choose.
proba vector of probability weights for obtaining the elements of the vector being sampled.